==> nextcloud-31.0.9.tgz: nextcloud/apps/systemtags/l10n/ru.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системная метка «%1$s» создана",
    "Added system tag {systemtag}" : "Создана системная метка «{systemtag}»",
    "Added system tag %1$s" : "Создана системная метка «%1$s»",
    "%1$s added system tag %2$s" : "%1$sсоздал(а) системную метку «%2$s»",
    "{actor} added system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "System tag %1$s removed by the system" : "Системная метка «%1$s» удалена",
    "Removed system tag {systemtag}" : "Удалена системная метка «{systemtag}»",
    "Removed system tag %1$s" : "Удалена системная метка «%1$s»",
    "%1$s removed system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} removed system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You created system tag %1$s" : "Вы создали системную метку «%1$s»",
    "You created system tag {systemtag}" : "Вы создали системную метку «{systemtag}»",
    "%1$s created system tag %2$s" : "%1$s создал(а) системную метку «%2$s»",
    "{actor} created system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "You deleted system tag %1$s" : "Вы удалили системную метку «%1$s»",
    "You deleted system tag {systemtag}" : "Вы удалили системную метку «{systemtag}»",
    "%1$s deleted system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} deleted system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You updated system tag %2$s to %1$s" : "Вы изменили системную метку «%2$s» на «%1$s»",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Вы изменили системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "%1$s updated system tag %3$s to %2$s" : "%1$s изменил(а) системную метку «%3$s» на «%2$s»",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} изменил(а) системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "System tag %2$s was added to %1$s by the system" : "«%1$s» помечен системной меткой «%2$s»",
    "System tag {systemtag} was added to {file} by the system" : "«{file}» помечен системной меткой «{systemtag}»",
    "You added system tag %2$s to %1$s" : "Вы пометили «%1$s» системной меткой «%2$s»",
    "You added system tag {systemtag} to {file}" : "Вы пометили «{file}» системной меткой «{systemtag}» ",
    "%1$s added system tag %3$s to %2$s" : "%1$s пометил(а) «%2$s» системной меткой «%3$s» ",
    "{actor} added system tag {systemtag} to {file}" : "{actor} пометил(а) «{file}» системной меткой «{systemtag}»",
    "System tag %2$s was removed from %1$s by the system" : "Системная метка «%2$s» убрана с «%1$s»",
    "System tag {systemtag} was removed from {file} by the system" : "Системная метка «{systemtag}» убрана с «{file}»",
    "You removed system tag %2$s from %1$s" : "Вы убрали системную метку «%2$s»  с «%1$s»",
    "You removed system tag {systemtag} from {file}" : "Вы убрали системную метку «{systemtag}» с «{file}»",
    "%1$s removed system tag %3$s from %2$s" : "%1$s убрал(а) системную метку «%3$s» с «%2$s»",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} убрал(а) системную метку «{systemtag}» с «{file}»",
    "%s (restricted)" : "%s (ограниченная)",
    "%s (invisible)" : "%s (невидимая)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
    "Files" : "Файлы",
    "Tags" : "Метки",
    "All tagged %s …" : "Все помеченные %s ...",
    "tagged %s" : "помеченные %s",
    "Collaborative tags" : "Метки совместной работы",
    "Collaborative tagging functionality which shares tags among people." : "Функционал совместных меток, который публикует метки среди пользователей.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функция совместного использования тегов, которая позволяет пользователям обмениваться тегами. Отлично подходит для команд.\n\t(Если вы являетесь поставщиком услуг с несколькими арендаторами, рекомендуется отключить это приложение, поскольку теги являются общими.)",
    "Public" : "Общая",
    "Restricted" : "Ограниченная",
    "Invisible" : "Невидимая",
    "Created tag" : "Метка создана",
    "Failed to create tag" : "Не удалось создать тег",
    "Updated tag" : "Метка обновлена",
    "Failed to update tag" : "Не удалось обновить метку",
    "Deleted tag" : "Метка удалена",
    "Failed to delete tag" : "Не удалось удалить тег",
    "Create or edit tags" : "Создание или изменение меток",
    "Search for a tag to edit" : "Поиск метки для изменения",
    "Collaborative tags …" : "Совместные теги ...",
    "No tags to select" : "Нет меток для выбора",
    "Tag name" : "Название метки",
    "Tag level" : "Уровень тега",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Delete" : "Удалить",
    "Reset" : "Сбросить",
    "Loading …" : "Загрузка…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} будет добавлен, а {tag2} будет удалён из 1 файла.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag}будет добавлен к 1 файлу.","{tag} будет добавлен к {count} файлам.","{tag} будет добавлен к {count} файлов.","{tag} будет добавлен к {count} файлов."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} будет удалён из 1 файла.","{tag} будет удалён из {count} файлов.","{tag} будет удалён из {count} файлов.","{tag} будет удалён из {count} файлов."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} и {lastTag} будут добавлены к 1 файлу.","{tags} и {lastTag} будут добавлены к {count} файлам.","{tags} и {lastTag} будут добавлены к {count}файлам.","{tags} и {lastTag} будут добавлены к {count} файлам."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} и {lastTag} будут удалены из 1 файла.","{tags} и {lastTag} будут удалены из {count} файлов.","{tags} и {lastTag} будут удалены из {count} файлов.","{tags} и {lastTag} будут удалены из {count} файлов."],
    "{displayName} (hidden)" : "{displayName} (скрыто)",
    "{displayName} (restricted)" : "{displayName} (ограничено)",
    "Only admins can create new tags" : "Только администраторы могут создать новые метки",
    "Failed to apply tags changes" : "Не удалось применить изменения тегов",
    "Manage tags" : "Управление метками",
    "Applying tags changes…" : "Изменение меток…",
    "Search or create tag" : "Найти или создать тег",
    "Search tag" : "Найти метку",
    "Change tag color" : "Изменить цвет метки",
    "Create new tag" : "Создать новый тег",
    "Cancel" : "Отмена",
    "Apply" : "Применить",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load selected tags" : "Не удалось загрузить выбранный тег",
    "Failed to select tag" : "Не удалось выбрать тег",
    "System admin disabled tag creation. You can only use existing ones." : "Создание меток отключено системным администратором. Вы можете использовать только существующие.",
    "Loading collaborative tags …" : "Загрузка совместных тегов ...",
    "Search or create collaborative tags" : "Поиск или создание совместных тегов",
    "No tags to select, type to create a new tag" : "Нет тегов для выбора. Введите что-нибудь для создания нового тега",
    "Unable to update setting" : "Не удалось обновить настройку",
    "System tag creation is now restricted to administrators" : "Создание системных меток теперь разрешено только администраторам",
    "System tag creation is now allowed for everybody" : "Создание системных меток теперь разрешено всем пользователям",
    "System tag management" : "Управление системными метками",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Если включено, только администраторы смогут создавать и редактировать метки. Пользователи всё ещё смогут назначать и удалять их с файлов.",
    "Restrict tag creation and editing to administrators" : "Разрешить создание и редактирование меток только администраторам",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные теги доступны для всех пользователей. Ограниченные теги видны пользователям, но не могут быть назначены ими. Невидимые теги предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
    "Assigned collaborative tags" : "Присвоенные теги для совместной работы",
    "Open in Files" : "Открыть в приложении «Файлы»",
    "List of tags and their associated files and folders." : "Список тегов и связанных с ними файлов и папок.",
    "No tags found" : "Меток не найдено",
    "Tags you have created will show up here." : "Здесь будут отображаться файлы с этой меткой",
    "Failed to load tag" : "Не удалось загрузить тег",
    "Failed to load last used tags" : "Не удалось загрузить последние использованные метки",
    "Missing \"Content-Location\" header" : "Отсутствует заголовок «Content-Location»",
    "A tag with the same name already exists" : "Метка с таким именем уже существует",
    "Failed to load tags for file" : "Не удалось загрузить метки для файла",
    "Failed to set tag for file" : "Не удалось поставить метку файлу",
    "Failed to delete tag for file" : "Не удалось удалить метку у файла",
    "File tags modification canceled" : "Изменение меток отменено",
    "Select or create tags to apply to all selected files" : "Выберите или создайте метки для применения ко всем выбранным файлам",
    "Select tags to apply to all selected files" : "Выберите метки для применения ко всем выбранным файлам",
    "Apply changes" : "Применить изменения"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/systemtags/l10n/ru.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системная метка «%1$s» создана",
    "Added system tag {systemtag}" : "Создана системная метка «{systemtag}»",
    "Added system tag %1$s" : "Создана системная метка «%1$s»",
    "%1$s added system tag %2$s" : "%1$sсоздал(а) системную метку «%2$s»",
    "{actor} added system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "System tag %1$s removed by the system" : "Системная метка «%1$s» удалена",
    "Removed system tag {systemtag}" : "Удалена системная метка «{systemtag}»",
    "Removed system tag %1$s" : "Удалена системная метка «%1$s»",
    "%1$s removed system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} removed system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You created system tag %1$s" : "Вы создали системную метку «%1$s»",
    "You created system tag {systemtag}" : "Вы создали системную метку «{systemtag}»",
    "%1$s created system tag %2$s" : "%1$s создал(а) системную метку «%2$s»",
    "{actor} created system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "You deleted system tag %1$s" : "Вы удалили системную метку «%1$s»",
    "You deleted system tag {systemtag}" : "Вы удалили системную метку «{systemtag}»",
    "%1$s deleted system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} deleted system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You updated system tag %2$s to %1$s" : "Вы изменили системную метку «%2$s» на «%1$s»",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Вы изменили системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "%1$s updated system tag %3$s to %2$s" : "%1$s изменил(а) системную метку «%3$s» на «%2$s»",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} изменил(а) системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "System tag %2$s was added to %1$s by the system" : "«%1$s» помечен системной меткой «%2$s»",
    "System tag {systemtag} was added to {file} by the system" : "«{file}» помечен системной меткой «{systemtag}»",
    "You added system tag %2$s to %1$s" : "Вы пометили «%1$s» системной меткой «%2$s»",
    "You added system tag {systemtag} to {file}" : "Вы пометили «{file}» системной меткой «{systemtag}» ",
    "%1$s added system tag %3$s to %2$s" : "%1$s пометил(а) «%2$s» системной меткой «%3$s» ",
    "{actor} added system tag {systemtag} to {file}" : "{actor} пометил(а) «{file}» системной меткой «{systemtag}»",
    "System tag %2$s was removed from %1$s by the system" : "Системная метка «%2$s» убрана с «%1$s»",
    "System tag {systemtag} was removed from {file} by the system" : "Системная метка «{systemtag}» убрана с «{file}»",
    "You removed system tag %2$s from %1$s" : "Вы убрали системную метку «%2$s»  с «%1$s»",
    "You removed system tag {systemtag} from {file}" : "Вы убрали системную метку «{systemtag}» с «{file}»",
    "%1$s removed system tag %3$s from %2$s" : "%1$s убрал(а) системную метку «%3$s» с «%2$s»",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} убрал(а) системную метку «{systemtag}» с «{file}»",
    "%s (restricted)" : "%s (ограниченная)",
    "%s (invisible)" : "%s (невидимая)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
    "Files" : "Файлы",
    "Tags" : "Метки",
    "All tagged %s …" : "Все помеченные %s ...",
    "tagged %s" : "помеченные %s",
    "Collaborative tags" : "Метки совместной работы",
    "Collaborative tagging functionality which shares tags among people." : "Функционал совместных меток, который публикует метки среди пользователей.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функция совместного использования меток, которая позволяет пользователям обмениваться метками. Отлично подходит для команд.\n\t(Если вы являетесь поставщиком услуг с несколькими арендаторами, рекомендуется отключить это приложение, поскольку метки являются общими.)",
    "Public" : "Общая",
    "Restricted" : "Ограниченная",
    "Invisible" : "Невидимая",
    "Created tag" : "Метка создана",
    "Failed to create tag" : "Не удалось создать метку",
    "Updated tag" : "Метка обновлена",
    "Failed to update tag" : "Не удалось обновить метку",
    "Deleted tag" : "Метка удалена",
    "Failed to delete tag" : "Не удалось удалить метку",
    "Create or edit tags" : "Создание или изменение меток",
    "Search for a tag to edit" : "Поиск метки для изменения",
    "Collaborative tags …" : "Совместные метки …",
    "No tags to select" : "Нет меток для выбора",
    "Tag name" : "Название метки",
    "Tag level" : "Уровень метки",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Delete" : "Удалить",
    "Reset" : "Сбросить",
    "Loading …" : "Загрузка …",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} будет добавлен, а {tag2} будет удалён из 1 файла.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов.","{tag1} будет добавлен, а {tag2} будет удалён из {count} файлов."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag}будет добавлен к 1 файлу.","{tag} будет добавлен к {count} файлам.","{tag} будет добавлен к {count} файлов.","{tag} будет добавлен к {count} файлов."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} будет удалён из 1 файла.","{tag} будет удалён из {count} файлов.","{tag} будет удалён из {count} файлов.","{tag} будет удалён из {count} файлов."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} и {lastTag} будут добавлены к 1 файлу.","{tags} и {lastTag} будут добавлены к {count} файлам.","{tags} и {lastTag} будут добавлены к {count}файлам.","{tags} и {lastTag} будут добавлены к {count} файлам."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} и {lastTag} будут удалены из 1 файла.","{tags} и {lastTag} будут удалены из {count} файлов.","{tags} и {lastTag} будут удалены из {count} файлов.","{tags} и {lastTag} будут удалены из {count} файлов."],
    "{displayName} (hidden)" : "{displayName} (скрыто)",
    "{displayName} (restricted)" : "{displayName} (ограничено)",
    "Only admins can create new tags" : "Только администраторы могут создать новые метки",
    "Failed to apply tags changes" : "Не удалось применить изменения меток",
    "Manage tags" : "Управление метками",
    "Applying tags changes…" : "Изменение меток…",
    "Search or create tag" : "Найти или создать метку",
    "Search tag" : "Найти метку",
    "Change tag color" : "Изменить цвет метки",
    "Create new tag" : "Создать новую метку",
    "Choose tags for the selected files" : "Укажите метки для выбранных файлов",
    "Cancel" : "Отмена",
    "Apply" : "Применить",
    "Failed to load selected tags" : "Не удалось загрузить выбранную метку",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to select tag" : "Не удалось выбрать метку",
    "System admin disabled tag creation. You can only use existing ones." : "Создание меток отключено системным администратором. Вы можете использовать только существующие.",
    "Loading collaborative tags …" : "Загрузка совместных меток …",
    "Search or create collaborative tags" : "Поиск или создание совместных меток",
    "No tags to select, type to create a new tag" : "Нет меток для выбора. Введите что-нибудь для создания новой метки",
    "Unable to update setting" : "Не удалось обновить настройку",
    "System tag creation is now restricted to administrators" : "Создание системных меток теперь разрешено только администраторам",
    "System tag creation is now allowed for everybody" : "Создание системных меток теперь разрешено всем пользователям",
    "System tag management" : "Управление системными метками",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Если включено, только администраторы смогут создавать и редактировать метки. Пользователи всё ещё смогут назначать и удалять их с файлов.",
    "Restrict tag creation and editing to administrators" : "Разрешить создание и редактирование меток только администраторам",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные метки доступны для всех пользователей. Ограниченные метки видны пользователям, но не могут быть назначены ими. Невидимые метки предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
    "Assigned collaborative tags" : "Присвоенные метки для совместной работы",
    "Open in Files" : "Открыть в приложении «Файлы»",
    "List of tags and their associated files and folders." : "Список меток и связанных с ними файлов и папок.",
    "No tags found" : "Меток не найдено",
    "Tags you have created will show up here." : "Здесь будут отображаться файлы с этой меткой",
    "Failed to load tag" : "Не удалось загрузить метку",
    "Failed to load last used tags" : "Не удалось загрузить последние использованные метки",
    "Missing \"Content-Location\" header" : "Отсутствует заголовок «Content-Location»",
    "A tag with the same name already exists" : "Метка с таким именем уже существует",
    "Failed to load tags for file" : "Не удалось загрузить метки для файла",
    "Failed to set tag for file" : "Не удалось поставить метку файлу",
    "Failed to delete tag for file" : "Не удалось удалить метку у файла",
    "Collaborative tags …" : "Совместные метки ...",
    "Loading …" : "Загрузка…",
    "File tags modification canceled" : "Изменение меток отменено",
    "Select or create tags to apply to all selected files" : "Выберите или создайте метки для применения ко всем выбранным файлам",
    "Select tags to apply to all selected files" : "Выберите метки для применения ко всем выбранным файлам",
    "Apply changes" : "Применить изменения",
    "Loading collaborative tags …" : "Загрузка совместных меток ..."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
